Module: HashDeepDiff::ActsAsHash::InstanceMethods

Defined in:
lib/hash_deep_diff/acts_as_hash.rb

Overview

We assume that the class will initialize instance variable @delta that will return a representation of an instance of a class as a Hash object

Instance Method Summary collapse

Instance Method Details

#to_hObject

a Hash representation of an object



21
22
23
# File 'lib/hash_deep_diff/acts_as_hash.rb', line 21

def to_h
  to_hash
end

#to_hashObject

a Hash representation of an object



26
27
28
# File 'lib/hash_deep_diff/acts_as_hash.rb', line 26

def to_hash
  @delta
end